@@ -5,7 +5,7 @@ from fastapi.middleware.cors import CORSMiddleware
 from fastapi.responses import JSONResponse
 
 from gateau_api.exceptions import PlayerNotFound
-from gateau_api.routers import desktop_client, web_app
+from gateau_api.routers import firebase_authed, unauthed
 
 logger = logging.getLogger(__name__)
 
@@ -21,8 +21,8 @@ app.add_middleware(
 )
 
 
-app.include_router(web_app.router)
-app.include_router(desktop_client.router)
+app.include_router(unauthed.router)
+app.include_router(firebase_authed.router)
 
 
 @app.exception_handler(PlayerNotFound)
